##  Summary
In this tutorial, you learned how to configure your system using the scaffolder of the LeanIX Reporting CLI, which enables you to create a project skeleton equipped with all the necessary files and dependencies for building custom reports.
